# frozen_string_literal: true

if defined?(ActionMailer)
  module Negroni
    # @!parse
    #   # Mailer for all auth-related mail
    #   class Mailer < ActionMailer::Base; end
    #
    # The base mailer for all emails
    class Mailer < Negroni.parent_mailer.constantize
      include Negroni::Mailers::Helpers

      # Sends `record` instructions to reset their password using `token`
      #
      # @param record [Object, #email] the record to send instructions
      # @param token [String] the token needed to reset the password
      # @param options [Hash] a hash of options for the mail
      #
      def reset_password_instructions(record, token, options = {})
        @token = token
        negroni_mail(record, :reset_password_instructions, options)
      end

      # Sends `record` instructions to unlock their account using `token`
      #
      # @param record [Object, #email] the record to send instructions
      # @param token [String] the token needed to reset the password
      # @param options [Hash] a hash of options for the mail
      #
      def unlock_instructions(record, token, options = {})
        @token = token
        negroni_mail(record, :unlock_instructions, options)
      end

      # Sends `record` a notification of password changes
      #
      # @param record [Object, #email] the record to send instructions
      # @param options [Hash] a hash of options for the mail
      #
      def password_change(record, options = {})
        negroni_mail(record, :password_change, options)
      end
    end
  end
end
