# frozen_string_literal: true

module Negroni
  # The Rails engine
  class Engine < ::Rails::Engine
    isolate_namespace Negroni

    config.generators do |g|
      g.api_only = true
      g.test_framework :rspec, fixture_replacement: :factory_girl
      g.factory_girl dir: 'spec/factories'
    end

    config.negroni = Negroni

    initializer 'negroni.omniauth', after: :load_config_initializers,
                                    before: :build_middleware_stack do |app|
      Negroni.omniauth_configs.each do |_provider, config|
        app.middleware.use config.strategy_class, *config.args do |strategy|
          config.strategy = strategy
        end
      end
    end

    initializer 'negroni.secret_key' do |app|
      Negroni.secret_key ||= app.secrets.secret_key_base
      Negroni.token_secret ||= app.secrets.secret_key_base

      Negroni.token_generator ||=
        if (secret_key = Negroni.secret_key)
          Negroni::TokenGenerator.new(secret_key: secret_key)
        end
    end
  end
end
