# frozen_string_literal: true

require 'negroni/omniauth'

module Negroni
  module Models
    # Adds OmniAuth support to your model.
    #
    # ## Options
    #
    # Omniauthable adds the following options to negroni:
    #
    #   * `omniauth_providers`: Which providers are available to this model.
    #           It expects an array.
    #
    # @example
    #   negroni :authenticable, :omniauthable, omniauth_providers: [:twitter]
    #
    module Omniauthable
      extend ActiveSupport::Concern

      # Required fields for this module (_none_)
      def self.required_fields(_klass = nil)
        []
      end

      # Configuration options
      module ClassMethods
        Negroni::Models.config(self, :omniauth_providers)
      end
    end
  end
end
